==> kadu_0.6.5.1.orig.tar.gz: kadu/modules/history/translations/history_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl">
<defaultcodec></defaultcodec>
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Zapisuj wiadomości w historii</translation>
    </message>
    <message>
        <source>Status changes</source>
        <translation>Zmiany statusów</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation>Pokazuj zmiany statusów</translation>
    </message>
    <message>
        <source>Show status changes in history</source>
        <translation>Pokazuje zmiany statusów w historii</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Zapisuj zmiany statusów</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Zapisuje zmiany statusów w historii</translation>
    </message>
    <message>
        <source>Citation</source>
        <translation>Cytowanie</translation>
    </message>
    <message>
        <source>Message citation in chat window</source>
        <translation>Cytowanie historii w oknie rozmowy</translation>
    </message>
    <message>
        <source>Don&apos;t cite messages older than</source>
        <translation>Nie cytuj historii starszej niż</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Pokaż historię</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <source>Find &amp;next</source>
        <translation>Znajdź &amp;następny</translation>
    </message>
    <message>
        <source>Find &amp;previous</source>
        <translation>Znajdź &amp;poprzedni</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Ukryty</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Niedostępny</translation>
    </message>
    <message>
        <source>Uins</source>
        <translation>Numery GG</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation>Pokaż zmiany statusu</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nieznany</translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <source>Clear history?</source>
        <translation>Wyczyścić historię?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <source>Show history</source>
        <translation>Pokaż historię</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Wyczyść historię</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>dni: %1 godzin: %2</translation>
    </message>
    <message>
        <source>The following users were deleted:
%0Do you want to remove history as well?</source>
        <translation>Następujący użytkownicy zostali usunięci:
%0Czy chcesz usunąć ich z historii?</translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <source>Search history</source>
        <translation>Przeszukaj historię</translation>
    </message>
    <message>
        <source>&amp;From:</source>
        <translation>&amp;Od:</translation>
    </message>
    <message>
        <source>day</source>
        <translation>dzień</translation>
    </message>
    <message>
        <source>month</source>
        <translation>miesiąc</translation>
    </message>
    <message>
        <source>year</source>
        <translation>rok</translation>
    </message>
    <message>
        <source>hour</source>
        <translation>godz.</translation>
    </message>
    <message>
        <source>minute</source>
        <translation>min.</translation>
    </message>
    <message>
        <source>Find Criteria</source>
        <translation>Kryteria wyszukiwania</translation>
    </message>
    <message>
        <source>&amp;Pattern</source>
        <translation>&amp;Wzorzec</translation>
    </message>
    <message>
        <source>&amp;Status</source>
        <translation>&amp;Status</translation>
    </message>
    <message>
        <source>Pattern</source>
        <translation>Wzorzec</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>&amp;Reverse find</source>
        <translation>&amp;Szukaj wstecz</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.3.orig.tar.gz: kadu/modules/history/translations/history_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Zapisuj wiadomości w historii</translation>
    </message>
    <message>
        <source>Status changes</source>
        <translation>Zmiany statusów</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation>Pokazuj zmiany statusów</translation>
    </message>
    <message>
        <source>Show status changes in history</source>
        <translation>Pokazuje zmiany statusów w historii</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Zapisuj zmiany statusów</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Zapisuje zmiany statusów w historii</translation>
    </message>
    <message>
        <source>Citation</source>
        <translation>Cytowanie</translation>
    </message>
    <message>
        <source>Message citation in chat window</source>
        <translation>Cytowanie historii w oknie rozmowy</translation>
    </message>
    <message>
        <source>Don&apos;t cite messages older than</source>
        <translation>Nie cytuj historii starszej niż</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Pokaż historię</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <source>Find &amp;next</source>
        <translation>Znajdź &amp;następny</translation>
    </message>
    <message>
        <source>Find &amp;previous</source>
        <translation>Znajdź &amp;poprzedni</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Ukryty</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Niedostępny</translation>
    </message>
    <message>
        <source>Uins</source>
        <translation>Numery GG</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation>Pokaż zmiany statusu</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nieznany</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Wyczyść historię</translation>
    </message>
    <message>
        <source>Rebuild index</source>
        <translation>Przebuduj indeks</translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <source>Clear history?</source>
        <translation>Wyczyścić historię?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Error opening history file </source>
        <translation>Nie można otworzyć pliku historii </translation>
    </message>
    <message>
        <source>Error opening sms history file </source>
        <translation>Nie można otworzyć pliku historii smsów </translation>
    </message>
    <message>
        <source>Error opening new history file </source>
        <translation>Nie można otworzyć nowegu pliku historii </translation>
    </message>
    <message>
        <source>Error opening new sms history file </source>
        <translation>Nie można otworzyć nowego pliku historii smsów </translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <source>Show history</source>
        <translation>Pokaż historię</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Wyczyść historię</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>dni: %1 godzin: %2</translation>
    </message>
    <message>
        <source>The following users were deleted:
%0Do you want to remove history as well?</source>
        <translation>Następujący użytkownicy zostali usunięci:
%0Czy chcesz usunąć ich z historii?</translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <source>Search history</source>
        <translation>Przeszukaj historię</translation>
    </message>
    <message>
        <source>&amp;From:</source>
        <translation>&amp;Od:</translation>
    </message>
    <message>
        <source>day</source>
        <translation>dzień</translation>
    </message>
    <message>
        <source>month</source>
        <translation>miesiąc</translation>
    </message>
    <message>
        <source>year</source>
        <translation>rok</translation>
    </message>
    <message>
        <source>hour</source>
        <translation>godzina</translation>
    </message>
    <message>
        <source>minute</source>
        <translation>minuta</translation>
    </message>
    <message>
        <source>Find Criteria</source>
        <translation>Kryteria wyszukiwania</translation>
    </message>
    <message>
        <source>&amp;Pattern</source>
        <translation>&amp;Wzorzec</translation>
    </message>
    <message>
        <source>&amp;Status</source>
        <translation>&amp;Status</translation>
    </message>
    <message>
        <source>Pattern</source>
        <translation>Wzorzec</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>&amp;Reverse find</source>
        <translation>&amp;Szukaj wstecz</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
</context>
</TS>
